import { createApp } from 'vue'
import { createPinia } from 'pinia'
import { definePreset } from '@primeuix/themes'
import Aura from '@primeuix/themes/aura'
import PrimeVue from 'primevue/config'
import ToastService from 'primevue/toastservice'
import Tooltip from 'primevue/tooltip'
import 'primeicons/primeicons.css'

import { router } from './router'
import App from './App.vue'

const pinia = createPinia()
const app = createApp(App)

const themePreset = definePreset(Aura, {
  semantic: {
    primary: {
      50: '{sky.50}',
      100: '{sky.100}',
      200: '{sky.200}',
      300: '{sky.300}',
      400: '{sky.400}',
      500: '{sky.500}',
      600: '{sky.600}',
      700: '{sky.700}',
      800: '{sky.800}',
      900: '{sky.900}',
      950: '{sky.950}',
    },
  },
})

app
  .use(router)
  .use(pinia)
  .use(PrimeVue, {
    theme: {
      preset: themePreset,
      options: {
        darkModeSelector: '.dark-mode',
        cssLayer: false,
      },
    },
  })
  .use(ToastService)
  .directive('tooltip', Tooltip)
  .mount('#app')
